<!-- Screenshot fullscreen - full-width image with vertical scroll -->
<div style="width: 100%; min-height: 100vh; overflow: auto; background: #222; padding: 0; box-sizing: border-box; display: flex; justify-content: center; align-items: flex-start;">
    <img src="{{ output_path }}"
         alt="Screenshot of page"
         class="extractor-fullscreen screenshot-fullscreen"
         style="width: auto; max-width: 100%; height: auto; display: block;">
</div>
